==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/warcraft/dialogs_es.lua <==

dialogId("war-m-hrad", "font_small", "I am imprisoned under the castle.")
dialogStr("Estoy prisionero en el castillo.")


dialogId("war-m-ocel", "font_small", "How did the steel get into this castle?")
dialogStr("¿Cómo llegó el acero a este castillo?")


dialogId("war-v-vesnicane", "font_big", "Hold on, I`ll bring some peasants to help you.")
dialogStr("Espera un poco, voy a traer algunos paisanos para ayudarte.")


dialogId("war-m-peoni", "font_small", "These are not peasants but peons.")
dialogStr("Esos no son paisanos... son obreros.")


dialogId("war-v-doly", "font_big", "Do you think that these mines contain captain Silver`s treasure?")
dialogStr("¿Crees que estas minas tengan el tesoro del capitán Silver?")


dialogId("war-m-povazuji", "font_small", "I consider this highly unlikely.")
dialogStr("Lo considero altamente improbable.")


dialogId("war-m-kam", "font_small", "Where did we get us, again?")
dialogStr("¿Hasta donde llegamos, de nuevo?")


dialogId("war-v-povedome", "font_big", "I find it oddly familiar here.")
dialogStr("Encuentro a este lugar extrañamente familiar.")


dialogId("war-v-pohadka", "font_big", "When MS Word or another boring application is running on this machine, we, the computer game characters, get together in the C:\\WINDOWS\\CONFIG directory and talk.")
dialogStr("Cuando el MS Word u otra aplicación aburrida está funcionando en esta máquina, nosotros, los personajes de juegos de computador, entramos al directorio C:\\WINDOWS\\CONFIG y hablamos.")


dialogId("war-m-pichat", "font_small", "When we don`t know what to do, we play hide-and-seek in the registry. That`s why your Windows sometimes crashes if you don`t play any games for a long period of time.")
dialogStr("Cuando no sabemos que hacer, jugamos a las escondidas en el registro. Por eso tu Windows algunas veces se cae si no juegas nada por un largo período de tiempo.")


dialogId("war-v-prozradit", "font_big", "You shouldn`t give that away. I only wanted to say that it looks very similar to this level. So many computer game characters.")
dialogStr("No deberías de haber ido tan lejos. Yo solo quería decir que luce muy similar a este nivel. Tantos personajes de juegos de computador.")


dialogId("war-m-aznato", "font_small", "But it`s not so difficult to get out of there.")
dialogStr("Pero no es tan difícil salir de aquí.")


dialogId("war-v-blizzard", "font_big", "The makers of this game would like to express their admiration for the Blizzard Entertainment company and wish them many successful games.")
dialogStr("A los autores de este juego les gustaría expresar su admiración por la compañía Blizzard Entertainment y les desean muchos juegos exitosos.")


dialogId("war-m-hodiny", "font_small", "And they would also like to thank them for so many hours of neatly killed time.")
dialogStr("Y ellos también quisieran agradecerles por tantas horas matando el tiempo netamente.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/warcraft/dialogs_es.lua <==

dialogId("war-m-hrad", "font_small", "I am imprisoned under the castle.")
dialogStr("Estoy prisionero en el castillo.")


dialogId("war-m-ocel", "font_small", "How did the steel get into this castle?")
dialogStr("¿Cómo llegó el acero a este castillo?")


dialogId("war-v-vesnicane", "font_big", "Hold on, I’ll bring some peasants to help you.")
dialogStr("Espera un poco, voy a traer algunos paisanos para ayudarte.")


dialogId("war-m-peoni", "font_small", "These are not peasants but peons.")
dialogStr("Esos no son paisanos... son obreros.")


dialogId("war-v-doly", "font_big", "Do you think that these mines contain captain Silver’s treasure?")
dialogStr("¿Crees que estas minas tengan el tesoro del capitán Silver?")


dialogId("war-m-povazuji", "font_small", "I consider this highly unlikely.")
dialogStr("Lo considero altamente improbable.")


dialogId("war-m-kam", "font_small", "Where did we get us, again?")
dialogStr("¿Hasta donde llegamos, de nuevo?")


dialogId("war-v-povedome", "font_big", "I find it oddly familiar here.")
dialogStr("Encuentro a este lugar extrañamente familiar.")


dialogId("war-v-pohadka", "font_big", "When MS Word or another boring application is running on this machine, we, the computer game characters, get together in the C:\\WINDOWS\\CONFIG directory and talk.")
dialogStr("Cuando el MS Word u otra aplicación aburrida está funcionando en esta máquina, nosotros, los personajes de juegos de computador, entramos al directorio C:\\WINDOWS\\CONFIG y hablamos.")


dialogId("war-m-pichat", "font_small", "When we don’t know what to do, we play hide-and-seek in the registry. That’s why your Windows sometimes crashes if you don’t play any games for a long period of time.")
dialogStr("Cuando no sabemos que hacer, jugamos a las escondidas en el registro. Por eso tu Windows algunas veces se cae si no juegas nada por un largo período de tiempo.")


dialogId("war-v-prozradit", "font_big", "You shouldn’t give that away. I only wanted to say that it looks very similar to this level. So many computer game characters.")
dialogStr("No deberías de haber ido tan lejos. Yo solo quería decir que luce muy similar a este nivel. Tantos personajes de juegos de computador.")


dialogId("war-m-aznato", "font_small", "But it’s not so difficult to get out of there.")
dialogStr("Pero no es tan difícil salir de aquí.")


dialogId("war-v-blizzard", "font_big", "The makers of this game would like to express their admiration for the Blizzard Entertainment company and wish them many successful games.")
dialogStr("A los autores de este juego les gustaría expresar su admiración por la compañía Blizzard Entertainment y les desean muchos juegos exitosos.")


dialogId("war-m-hodiny", "font_small", "And they would also like to thank them for so many hours of neatly killed time.")
dialogStr("Y ellos también quisieran agradecerles por tantas horas matando el tiempo netamente.")
